# wf_core_data

Python tools for working with Wildflower Schools core data

## Tasks
* Consider splitting library into atomic libraries for each assessment and data source
* Update naming of submodules and functions to be more consistent across assessments
* NWEA: Add ability to handle more detailed data download (separate test event and student files)
